:orphan:

The Weblate Manual
==================

User docs
---------

.. include:: toc-user.rst

Administrator docs
------------------

.. include:: toc-admin.rst

Contributor docs
----------------

.. include:: toc-contrib.rst

Change History
--------------

.. include:: toc-changes.rst
